Arguments
template
A Raster* or Spatial* object to serve
as a template for cropping. If missing, all stations
will be downloaded!
label
A character string naming the study area.
elements
A character vector of elemets to extract.
Common elements include "tmin", "tmax", and "prcp".
raw.dir
A character string indicating where raw downloaded files should be put.
The directory will be created if missing. Defaults to "./RAW/GHCN/".
extraction.dir
A character string indicating where the extracted and cropped GHCN shapefiles should be put.
The directory will be created if missing. Defaults to "./EXTRACTIONS/GHCN/".
standardize
Select only common year/month/day? Defaults to FALSE.
force.redo
If an extraction for this template and label already exists, should a new one be created? Defaults to FALSE.