Learn R Programming

FedData (version 2.0.0)

get_ghcn_daily_station: Download and extract the daily data for a GHCN weather station.

Description

get_ghcn_daily_station returns a named list of data.frames, one for each elements. If elements is undefined, it returns all available weather tables for the station

Usage

get_ghcn_daily_station(ID, elements = NULL, raw.dir, standardize = F,
  force.redo = F)

Arguments

ID
A character string giving the station ID.
elements
A character vector of elemets to extract. Common elements include "tmin", "tmax", and "prcp".
raw.dir
A character string indicating where raw downloaded files should be put.
standardize
Select only common year/month/day? Defaults to FALSE.
force.redo
If this weather station has been downloaded before, should it be updated? Defaults to FALSE.

Value

  • A named list of data.frames, one for each elements.